Running photozs
===============

Parameters
~~~~~~~~~~

Photometric catalog
~~~~~~~~~~~~~~~~~~~

Execution
~~~~~~~~~

API
~~~

.. automodapi:: eazy.param
    :no-inheritance-diagram:

.. automodapi:: eazy.igm
    :no-inheritance-diagram:

.. automodapi:: eazy.photoz
    :no-inheritance-diagram:
